Wieso wird nicht gewarnt vor Zwangs Publikation von QSI auf MX linux?

Kuketz empfehlt MX linux.https://www.kuketz-blog.de/empfehlungsecke/#linux ‚vollständig geprüft: September 2026.‘
Leider erwähnt er nicht das Firefox mit Standard einstellungen geliefert wird, also Google verseucht.
Aber was mir noch viel mehr wundert ist das er Offensichtlich kein Bedenken hat das man, wenn man Hilfe auf das MX Linux Forum (und auf Linux Mint Forum) sucht eine Liste von kompletten System publizieren muss: Quick System Info. Sonst gibt es keine Hilfe ins Forum!
Das ist doch sehr merkwürdig? Man versucht sich zu schützen vor Big Tech aber zu gleicherzeit um Hilfe zu bekommen ist es erforderlich sein Totalen Hardware Info (QSI) Online zu publizieren!
Es wird hier ständig gewarnt und informiert über Sicherheitsmaßnahmen, Tracker Usw. aber der QSI der Rechner auf ein Linux Forum zu publizieren, ein fast kompletter Fingerprint (!) sei kein Problem?
Wirklich?!

  1. Die eierlegende Wollmilchsau, die alle Wünsche erfüllt, gibt es nicht. Irgendwo müssen Abstriche gemacht werden.
  2. Nur weil ein Browser vorinstalliert ist, muss dieser nicht verwendet werden.
  3. Einen Zwang, sich in den entsprechenden Foren zu beteiligen ist nicht gegeben.
  4. Ein Linuxnutzer mehr ist ein Windowsnutzer weniger.
  5. Jeder soll und muss für sich selbst entscheiden, wie viele Daten er von sich preisgeben will.

Ich meine, der google-verseuchte Browser hat nur Google als Standardsuchmaschine. Das ist schnell und einfach geändert.

Die inxi-Abfrage ist mit Sicherheit kein Fingerprint. Es gibt dort nichts, was auf Max Mustermann aus Lüdenscheid hindeutet. Alle externen IP-Adressen, alle Seriennummern der Geräte werden ausgeblendet. Die interne IP-Adresse (mein 192.168.178.1, ja ich habe eine FritzBox) gibt es einige hunderttausende Mal in Deutschland.

Dein Browser macht regelmäßig mehr über dich bekannt.

Und denke bitte daran, da sitzen unbezahlte Menschen, die in ihrer viel zu knappen Restlebenszeit versuchen dir den Arsch zu retten. Was meinst du wie nervig es ist, wenn man seitenlang um Angaben betteln muss und die wichtigste ganz zum Schuss kommt. Da sind die wirklich helfenden schon lange nicht mehr dabei.

Wo überall wird denn Firefox (NICHT ein Derivat!) mit anderen Einstellungen (statt Standard-Einstellungen) ausgeliefert?

Danke, du sprichst mir aus der Seele.

Mit was für Einstellungen denn sonst??? Und natürlich gilt der Satz:

Firefox ist im Auslieferungszustand (ebenso wie Brave) kein datenschutzfreundlicher Browser.

https://www.kuketz-blog.de/brave-und-firefox-sichere-und-datenschutzfreundliche-browser-teil-2/

Es gibt keinen Zwang; niemand zwingt dich, Hilfe im MX Linux Forum in Anspruch zu nehmen, wenn Dir selbst diese bescheidenen Wünsche zu viel sind.

Übrigens gab’s so eine Diskussion(*) schon einmal:
Bitte vollständige Hardware-Liste im Forum veröffentlichen!

(*) in der Plauderecke, Zugriff erst nach Login möglich

Naja, ein bisschen was gibt es tatsächlich. Aber dagegen hilft:

------------------------------------------------------------------------------
Filter Options:
     --host    Turn on hostname for -S. Overrides -z.
     --no-host Turn off hostname for -S. Useful if showing report from servers 
               etc. Activated by -z as well. 
 -z, --filter  Adds security filters for IP/MAC addresses, serial numbers, 
               location (-w), user home directory name, host name. Default on 
               for IRC clients. 
     --za,--filter-all
               Shortcut, triggers -z, --zl, --zu, --zv.
     --zl,--filter-label
               Filters out partition labels in -j, -o, -p, -P, -Sa.
     --zu,--filter-uuid
               Filters out partition UUIDs in -j, -o, -p, -P, -Sa, board UUIDs 
               in -Mxxx. 
     --zv,--filter-vulnerabilities
               Filters out Vulnerabilities report in -Ca.
 -Z, --no-filter
               Disable output filters. Useful for debugging networking issues 
               in IRC, or you needed to use --tty, for example. 
------------------------------------------------------------------------------

Stimmt schon - daher ist die übliche Abfrage:

inxi -Fz

Genau, dann sind alle Fingerzeige auf einen, alle Seriennummern von Teilen raus.

Es wird suggeriert, dass MX/Mint standardmäßig ein sicheres Betriebssystem ist. Nur 1ne kleine kritische Anmerkung, und schon kommen irrelevante Argumente und Bemerkungen ins Spiel.
Als ob die vollständige Hardware-Liste nicht schon eine riesige Vielzahl anderer PCs ausschließen würde. Wenn man darüber hinaus beispielsweise die Festplatte durch eine SSD ersetzt hat, fällt man noch mehr auf. Das lässt sich nicht leugnen.

(Textauszeichnung (fett) durch mich)

Hä?

Z.B.:

Oder:

Bei Debian.

Oh, aha.

Was machen die konkret? Zumindest heißt das Paket weiterhin firefox (und nicht kenntlich als Derivat i.w.S. oder speziell angepasste Version — wie z.B. Fennec für Android).

Oh…

Ich habe gerade https://wiki.debian.org/Firefox gefunden. :slight_smile: Dort u.a.:

Firefox makes a number of automated connections to Mozilla’s (and other’s) servers without explicitly asking the user for approval. Mozilla documents that list in the How to stop Firefox from making automatic connections page. Here is a table of the above parameters and how Debian diverges from the upstream default:

(Zu Google innerhalb von Firefox habe ich so schnell allerdings nichts gefunden…)

OK, bitte: mea culpa!

Aber: sonst noch welche (nennenswerte — nicht Nischen) Distributionen (Plural)?

Also ich denke das Problem ist Offensichtlich :slight_smile:

Wenn man eine Distribution gefunden hat die alle persönlichen Auswahlkriterien erfüllt, muss man nicht weitere suchen wenn man wenig Zeit hat :wink: Insofern sind mir keine weiteren bekannt.

Es gibt eine weitere Distribution die entsprechend ähnlich mit dem Paket verfährt, hierbei jedoch auf die neuste Version setzt und noch weitergehende Maßnahmen durchführt:
Trisquel GNU/Linux. Dieser Browser wird aufgrund der Eingriffe aber nicht mehr Firefox genannt und entspricht damit deinem strengen Kriterium nicht.

Wem Privacy bereits im Standardauslieferungszustand und darüberhinaus wichtig sind, sollte sich von Distributionen fernhalten, die am Mainstream ausgerichtet und Windows-Umsteiger zur Zielgruppe haben. Also Debian wenn man reine Debian-Basis möchte oder Trisquel, wenn man Ubuntu als Basis möchte. OpenSUSE war bei meinem letzten Test -eingeschränkt- auch so ein Kandidat. Vor diesen muss auch nicht gewarnt werden.
Bzw. vor denen warnen dann nur die CVE-Cheferbsenzähler :wink:

Die Linux-Distro ist aber nicht schuld, wenn einzelne Programme wie der Firefox im Auslieferungszustand nicht ganz „sauber“ sind, was Datenschutz angeht. Ich bin überzeugter Mint-Nutzer und nutze für meine Webseiten-Administration den Firefox, den ich mir entsprechend nach dem Kuketz-Blog datenschutzfreundlich konfiguriert habe. Niemand ist gezwungen, den Browser zu nehmen, der mit Linux kommt. Wie man eine Software deinstalliert, dass weißt du?

Zu den Hardware-Infos: Willst du mir weißmachen, dass nach entfernen aller eindeutigen Informationen wie Serienummern, jemand anhand z.B. einer Festplatte als Christa Meier oder Kevin Schulze identifiziert werden kann? Ich habe eine Samsung SSD 860 EVO 256 GB im Rechner verbaut. Und wer bin ich? Die Samsung SSD ist Massenware und wenn die Informationen entfernt werden, die eine Hardware eindeutig identifizieren, wo ist da das Problem? Außerdem, wenn meine Seriennummer der SSD 47111148 wäre, wie willst du dann explizit auf mich kommen? Da hätte ich gern mal ein paar schlüssige Argumente von Dir gehört

Ja, OK. — Die Frage war ja auch nicht explizit auf Dich bezogen, sondern eher allgemein und an @Offensichtlich (da er es vorher mit Firefox und seinen Einstellungen so hingestellt hatte…).

Ja, ich finde durchaus, das sollte schon gekennzeichnet sein! Eine Distribution, die selbst baut (also nicht z.B. Flatpaks…), sollte möglichst nahe am Original bauen… lediglich mit Specs und Patches für Kompatibilität und/oder Optimierungen (CPU-Architektur, Compiler-Flags).

Aber das dort ist ja schon eine „wesentliche“ Änderung des Originals. Das sollte m.M.n. gekennzeichnet sein. Manche machen das ja.

Naja… Grundsätzlich schon! Aber es gibt sie halt, die Diskussionen:

  • Rolling Release vs. Fixed Version Release (@Chief würde sagen, unbedingt nur Rolling! :wink: )
  • wenn ersteres, wie schnell (z.B. Tumbleweed vs Slowroll bei openSUSE) oder bei letzterem, wie oft (z.B. Fedora 1/2 Jahr, Leap 1 Jahr, Debian > 1 Jahr)
  • eigene Patches am Kernel
  • systemd — oder eben nicht (wie viele nicht-systemd es in 10 Jahren noch geben mag?)
  • glibc oder musl (z.B. → Void Linux)
  • hardenend_malloc (z.B. → secureblue)
  • (schon) Wayland — oder noch X

Im wesentlichen kann ich mich in diesem Thread nur den Hinweise von @o0ps anschliessen und wollte hier keine Distributionsdiskussion auslösen.
MIr ging es lediglich darum, @Offensichtlich eine zu seiner Kritik passende Auswahl alternativer Distribuitionen zu nennen.

Selbstverständlich. Wie in meinerm Beitrag erwähnt, macht das Trisquel-Projekt das ja auch exakt so und deren Änderungen sind lediglich im Sinne des privacy-orientierten Nutzers.
Deswegen habe ich diese Distribution im Kontext des TE erwähnt.
Damit ist aber keine Kritik an der notwendigen Umbenennung der Software verbunden.

Die Existenz von Diskussionen sagt zum Glück nichts über deren Sinnhaftigkeit aus :slight_smile:

curl hat ziemlich gute Privacy-Defaults…

…SCNR